summaryrefslogtreecommitdiff
path: root/drivers/staging/tidspbridge/include/dspbridge/dbdcd.h
diff options
context:
space:
mode:
authorRene Sapiens <rene.sapiens@ti.com>2010-07-10 02:23:59 (GMT)
committerGreg Kroah-Hartman <gregkh@suse.de>2010-07-22 17:45:35 (GMT)
commita5120278008a5f48634085c23a70f1153065765d (patch)
tree3f27183216489e4f5fa74e907279bb6cbe34af80 /drivers/staging/tidspbridge/include/dspbridge/dbdcd.h
parentaa09b091267694befb9459f22bed2d6437fb59f8 (diff)
downloadlinux-fsl-qoriq-a5120278008a5f48634085c23a70f1153065765d.tar.xz
staging: ti dspbridge: Rename words with camel case.
The intention of this patch is to rename the remaining variables with camel case. Variables will be renamed avoiding camel case and Hungarian notation. The words to be renamed in this patch are: ======================================== pdwSize to buff_size pdwState to board_state pdwValue to value pdwVersion to version pElemExisting to elem_existing pEntry to entry pExists to exists pfEnablePerf to enable_perf pGenObj to gen_obj phChnlMgr to channel_mgr phChnl to chnl phCodMgr to cod_mgr phDCDHandle to dcd_handle phDcdMgr to dcd_mgr phDehMgr to deh_manager ======================================== Signed-off-by: Rene Sapiens <rene.sapiens@ti.com> Signed-off-by: Greg Kroah-Hartman <gregkh@suse.de>
Diffstat (limited to 'drivers/staging/tidspbridge/include/dspbridge/dbdcd.h')
-rw-r--r--drivers/staging/tidspbridge/include/dspbridge/dbdcd.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/drivers/staging/tidspbridge/include/dspbridge/dbdcd.h b/drivers/staging/tidspbridge/include/dspbridge/dbdcd.h
index 2a2b655..8c06272 100644
--- a/drivers/staging/tidspbridge/include/dspbridge/dbdcd.h
+++ b/drivers/staging/tidspbridge/include/dspbridge/dbdcd.h
@@ -77,7 +77,7 @@ extern int dcd_auto_unregister(IN struct dcd_manager *hdcd_mgr,
* This function creates a DCD module manager.
* Parameters:
* pszZlDllName: Pointer to a DLL name string.
* phDcdMgr: A pointer to a DCD manager handle.
* Returns:
* 0: Success.
* -ENOMEM: Unable to allocate memory for DCD manager handle.
@@ -85,12 +85,12 @@ extern int dcd_auto_unregister(IN struct dcd_manager *hdcd_mgr,
* Requires:
* DCD initialized.
* pszZlDllName is non-NULL.
- * phDcdMgr is non-NULL.
+ * dcd_mgr is non-NULL.
* Ensures:
* A DCD manager handle is created.
*/
extern int dcd_create_manager(IN char *pszZlDllName,
- OUT struct dcd_manager **phDcdMgr);
+ OUT struct dcd_manager **dcd_mgr);
/*
* ======== dcd_destroy_manager ========
@@ -215,7 +215,7 @@ extern int dcd_get_num_dep_libs(IN struct dcd_manager *hdcd_mgr,
* uuid_obj: Pointer to a dsp_uuid that represents a unique DSP/BIOS
* Bridge object.
* pstrLibName: Buffer to hold library name.
* pdwSize: Contains buffer size. Set to string size on output.
* phase: Which phase to load
* phase_split: Are phases in multiple libraries
* Returns:
@@ -226,13 +226,13 @@ extern int dcd_get_num_dep_libs(IN struct dcd_manager *hdcd_mgr,
* Valid hdcd_mgr.
* pstrLibName != NULL.
* uuid_obj != NULL
- * pdwSize != NULL.
+ * buff_size != NULL.
* Ensures:
*/
extern int dcd_get_library_name(IN struct dcd_manager *hdcd_mgr,
IN struct dsp_uuid *uuid_obj,
IN OUT char *pstrLibName,
- IN OUT u32 *pdwSize,
+ IN OUT u32 *buff_size,
IN enum nldr_phase phase,
OUT bool *phase_split);
@@ -77,7 +77,7 @@ extern int dcd_auto_unregister(IN struct dcd_manager *hdcd_mgr,
* Parameters:
* pszZlDllName: Pointer to a DLL name string.
- * phDcdMgr: A pointer to a DCD manager handle.
+ * dcd_mgr: A pointer to a DCD manager handle.
* Returns:
* 0: Success.
@@ -215,7 +215,7 @@ extern int dcd_get_num_dep_libs(IN struct dcd_manager *hdcd_mgr,
* Bridge object.
* pstrLibName: Buffer to hold library name.
- * pdwSize: Contains buffer size. Set to string size on output.
+ * buff_size: Contains buffer size. Set to string size on output.
* phase: Which phase to load
* phase_split: Are phases in multiple libraries